/*
 * This file and everything in this package is covered under
 * the OPENdj Software License.  See the LICENSE file at the top
 * level of this package for full details.  A copy of the license
 * is also available at: http://opendj.org/docs/licenses/LICENSE.opendj
 * 
 * Copyright 2001 DAX Interactive, LLC.
 *
 * $Author: jonathan $
 * $Revision: 1.1.1.1 $
 * $Header: /home/cvspublic/opendj/opendj-share/src/org/opendj/share/ChannelTime.java,v 1.1.1.1 2001/09/29 20:39:30 jonathan Exp $
 * $Log: ChannelTime.java,v $
 * Revision 1.1.1.1  2001/09/29 20:39:30  jonathan
 * Imported opendj-share
 *
 */
package org.opendj.share;

import java.util.StringTokenizer;
import java.util.Date;

public class ChannelTime {

    public static final int NONE       = 0;
    public static final int ONAIR      = 1;

    public String name = null;
    public String path = null;
    public long delta  = -1;
    public long length = -1;
    public int special = NONE;

    // This is only used on the client side to 
    // work with the delta value
    public long recvTime = -1;

    // This is only used on the server side to
    // get a little extra accuracy
    public long createTime = -1;

    public ChannelTime() {}

    public ChannelTime( String name, String path, long delta, long length ) {
        this.name = name;
        this.path = path;
        this.delta = delta;
        this.length = length;
        this.special = NONE;
    }

    public ChannelTime( String name, String path, long delta, long length, int special ) {
        this.name = name;
        this.path = path;
        this.delta = delta;
        this.length = length;
        this.special = special;
    }

    public String toString () {
        return "[ChannelTime name='" + name
            + "', delta=" + delta 
            + ", length=" + length
            + ", special=" + special
            + "]";
    }

    public static ChannelTime parseServerLine( String theServerLine ) {
        StringTokenizer st = new StringTokenizer(theServerLine, "|");
        // Skip the command
        st.nextToken();
        return new ChannelTime(st.nextToken(), 
                               st.nextToken(),
                               Long.parseLong(st.nextToken()),
                               Long.parseLong(st.nextToken()),
                               Integer.parseInt(st.nextToken()));
    }
}
