/*
 * This file and everything in this package is covered under
 * the OPENdj Software License.  See the LICENSE file at the top
 * level of this package for full details.  A copy of the license
 * is also available at: http://opendj.org/docs/licenses/LICENSE.opendj
 * 
 * Copyright 2001 DAX Interactive, LLC.
 *
 * $Author: jonathan $
 * $Revision: 1.1.1.1 $
 * $Header: /home/cvspublic/opendj/opendj-share/src/org/opendj/share/NestedException.java,v 1.1.1.1 2001/09/29 20:39:30 jonathan Exp $
 * $Log: NestedException.java,v $
 * Revision 1.1.1.1  2001/09/29 20:39:30  jonathan
 * Imported opendj-share
 *
 */
package org.opendj.share;

/**
 * Encapsulates an exception which may optionally have another exception nested within it.
 * When the toString method is called, any nested exceptions will also be displayed.
 *
 */
public abstract class NestedException extends Exception {

    protected Throwable itsT = null;

    public NestedException() {}

    public NestedException(String s) {
        super(s);
    }

    public NestedException(Throwable t) {
        super(t.toString());
        itsT = t;
    }

    public NestedException(String s, Throwable t) {
        super(s);
        itsT = t;
    }

    public Throwable getBaseThrowable() { return itsT; }

    public Exception getBaseException() { 
        if ( itsT instanceof Exception ) {
            return (Exception) itsT;
        }
        return new Exception("NestedException.getBaseException: BASE IS THROWABLE: "
                             + itsT.toString());
    }

    public String toString() { 
        if ( itsT != null ) {
            return super.toString() + "\nNESTED-EXCEPTION:\n" + itsT.toString();
        }
        return super.toString();
    }

}
